const urls = require('./utils/urls.js')
const network = require('./utils/network.js')
const brandConfig = require('./brand/config.js')
const router = require('./utils/router.js')
const routerInterceptor = require('./utils/routerInterceptor')

const livePlayer = requirePlugin('live-player-plugin')

App({
  copywriting: brandConfig.copywriting,
  brandConfig,
  urls,
  network,
  router,
  routerInterceptor,
  globalData: {
    userInfo: {},
    isLogin: false,
    isWarranty: false,
    hasSale: false,
    isWxwork: false,
    levels: [
      '影友',
      'LRC会员',
      '银卡会员',
      '金卡会员',
      '白金卡会员',
      '黑金卡会员'
    ],
    liveData: {
      roomid: '',
      openid: '',
      share_openid: ''
    }
  },

  sceneHandler: null,

  onLaunch() {},

  onShow(options) {
    console.log(options)
    if (
      options.scene === 1007 ||
      options.scene === 1008 ||
      options.scene === 1044 ||
      options.scene === 1058
    ) {
      livePlayer
        .getShareParams()
        .then(res => {
          network.liveLogin({
            share_openid: res.share_openid,
            room_id: res.room_id,
            scene: options.scene
          })
        })
        .catch(err => {
          console.log('get share params', err)
        })
    }
    this._warrantyCardCallBack(options.referrerInfo)
  },

  // 保修卡回调操作
  _warrantyCardCallBack(referrerInfo) {
    if (
      referrerInfo === undefined ||
      referrerInfo.appId !== 'wxeb490c6f9b154ef9'
    ) {
      return
    }

    this.globalData.isWarranty = true
    wx.switchTab({
      url: '/pages/member/mine/mine'
    })
  },

  // 静默登录
  login(cb) {
    const that = this
    network.login(res => {
      that.globalData.userInfo = res
      that.globalData.isLogin = true
      cb(res)
    })
  },

  // 获取用户unionid
  getUserInfo(param, cb) {
    const that = this
    network.post({
      url: urls.MINI_USERINFO,
      data: {
        encryptedData: param.encryptedData,
        iv: param.iv
      },
      success(res) {
        that.globalData.userInfo = res.data
        that.globalData.isLogin = true
        wx.setStorageSync('userInfo', res.data)
        cb()
      },
      complete() {
        wx.hideLoading()
      }
    })
  }
})
