const WxParse = require('../../utils/wxParse/wxParse.js')

const app = getApp()

app.routerInterceptor.checkLoginStatus({
  /**
   * 页面的初始数据
   */
  data: {
    kol: {},
    commodities: [],

    consumers: [],

    pack_id: 'FMHBanG9d9uCm9CAEAdMVa',
    pack: {},

    nums: [],
    total: 0,
    isLodding: false
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {
    wx.hideHomeButton()
    const { room_id } = options
    if (room_id !== undefined) {
      wx.redirectTo({
        url: `/pages/live/anchorHome/anchorHome?room_id=${room_id}`
      })

      return
    }
    this.getData()
  },

  getData() {
    const that = this
    app.network.post({
      url: app.urls.PACK,
      data: {
        pack_id: 'FMHBanG9d9uCm9CAEAdMVa'
      },
      success(res) {
        const { sales, pack, goods } = res.data
        const conusmers = sales.map(sale => {
          const s = sale
          s.content = sale.saleinfo.reduce(
            (accumulator, cur) => `${accumulator + cur.title} x ${cur.num} \n`,
            ''
          )
          s.created_at = that.timeago(s.created_at)
          return s
        })
        WxParse.wxParse('article', 'html', pack.pack_detail, that, 5)
        pack.pack_detail = ''

        const commodities = goods.map(commodity => {
          const c = commodity
          c.price /= 100
          return c
        })
        that.setData({
          kol: res.data.kol,
          commodities,
          nums: Array(res.data.goods.length).fill(0),
          consumers: conusmers,
          pack,
          isLodding: true
        })
      }
    })
  },

  bindstepperChanged(e) {
    const { nums, commodities } = this.data
    nums[e.currentTarget.dataset.index] = e.detail
    const total = commodities.reduce(
      (accumulator, cur, index) =>
        accumulator + (cur.price * 100 * nums[index]) / 100,
      0
    )

    this.setData({
      nums,
      total
    })
  },

  forbid() {},

  navigateToOrder() {
    const { nums } = this.data
    let { commodities } = this.data
    commodities = commodities
      .map((curr, index) => {
        return Object.assign(curr, { num: nums[index] })
      })
      .filter(curr => {
        return curr.num > 0
      })

    const that = this
    wx.navigateTo({
      url: '../order/order',
      success(res) {
        res.eventChannel.emit('acceptDataFromOpenerPage', {
          commodities,
          total: that.data.total,
          kol: that.data.kol,
          pack_id: that.data.pack_id
        })
      }
    })
  },

  getUserInfo(e) {
    if (e.detail.userInfo === undefined) {
      wx.showModal({
        title: '提示',
        content: '需要您的授权，才能继续报名',
        showCancel: false
      })
    } else {
      wx.showLoading({
        title: '登陆中'
      })

      const that = this
      app.getUserInfo(
        {
          iv: e.detail.iv,
          encryptedData: e.detail.encryptedData
        },
        () => {
          that.navigateToOrder()
        }
      )
    }
  },

  onShareAppMessage() {
    return {
      title: this.data.pack.title,
      path: '/pages/index/index'
    }
  },

  timeago(date) {
    // dateTimeStamp是一个时间毫秒，注意时间戳是秒的形式，在这个毫秒的基础上除以1000，就是十位数的时间戳。13位数的都是时间毫秒。
    const dateTimeStamp = new Date(
      Date.parse(date.replace(/-/g, '/'))
    ).getTime()

    const minute = 1000 * 60 // 把分，时，天，周，半个月，一个月用毫秒表示
    const hour = minute * 60
    const day = hour * 24
    const week = day * 7
    const month = day * 30
    const now = new Date().getTime() // 获取当前时间毫秒
    const diffValue = now - dateTimeStamp // 时间差

    if (diffValue < 0) {
      return ''
    }
    const minC = diffValue / minute // 计算时间差的分，时，天，周，月
    const hourC = diffValue / hour
    const dayC = diffValue / day
    const weekC = diffValue / week
    const monthC = diffValue / month
    let result = ''

    if (monthC >= 1 && monthC <= 3) {
      result = ` ${parseInt(monthC, 0)}月前`
    } else if (weekC >= 1 && weekC <= 3) {
      result = ` ${parseInt(weekC, 0)}周前`
    } else if (dayC >= 1 && dayC <= 6) {
      result = ` ${parseInt(dayC, 0)}天前`
    } else if (hourC >= 1 && hourC <= 23) {
      result = ` ${parseInt(hourC, 0)}小时前`
    } else if (minC >= 1 && minC <= 59) {
      result = ` ${parseInt(minC, 0)}分钟前`
    } else if (diffValue >= 0 && diffValue <= minute) {
      result = '刚刚'
    } else {
      const datetime = new Date()
      datetime.setTime(dateTimeStamp)
      const Nyear = datetime.getFullYear()
      const Nmonth =
        datetime.getMonth() + 1 < 10
          ? `0${datetime.getMonth() + 1}`
          : datetime.getMonth() + 1
      const Ndate =
        datetime.getDate() < 10 ? `0${datetime.getDate()}` : datetime.getDate()
      result = `${Nyear}-${Nmonth}-${Ndate}`
    }
    return result
  }
})
