const app = getApp()

Page({
  /**
   * Page initial data
   */
  data: {
    hasAddress: false,
    commodities: [],
    address: {},
    kol: {},
    pack_id: '',
    order_id: '',
    prepay_id: '',
    total: 0
  },

  onLoad() {
    const eventChannel = this.getOpenerEventChannel()
    const that = this
    const { userInfo } = app.globalData

    if (userInfo.consignee_name !== '' && userInfo.consignee_name !== null) {
      this.setData({
        address: {
          userName: userInfo.consignee_name,
          telNumber: userInfo.consignee_phone,
          detailInfo: userInfo.consignee_address
        },
        hasAddress: true
      })
    }

    eventChannel.on('acceptDataFromOpenerPage', data => {
      that.setData({
        commodities: data.commodities,
        total: data.total,
        kol: data.kol,
        pack_id: data.pack_id
      })
    })
  },

  navigateToAddress() {
    const that = this
    wx.chooseAddress({
      success: res => {
        res.detailInfo =
          res.provinceName + res.cityName + res.countyName + res.detailInfo
        that.setData({
          address: res,
          hasAddress: true
        })
      }
    })
  },

  confirm() {
    const that = this
    app.network.post({
      url: app.urls.ORDER_CREATE,
      data: {
        pack_id: this.data.pack_id,
        kol_id: this.data.kol.kol_id,
        total_fee: this.data.total * 100,
        goods_info: JSON.stringify(this.data.commodities),
        name: this.data.address.userName || '',
        phone: this.data.address.telNumber || '',
        address: this.data.address.detailInfo || '',
        body: '尖货接龙'
      },
      success(res1) {
        const { wxpay_params } = res1.data
        that.setData({
          order_id: res1.data.order_id,
          prepay_id: res1.data.prepay_id
        })
        wx.requestPayment({
          timeStamp: wxpay_params.timeStamp,
          nonceStr: wxpay_params.nonceStr,
          package: wxpay_params.package,
          signType: wxpay_params.signType,
          paySign: wxpay_params.paySign,
          success: _ => {
            wx.reLaunch({
              url: '/pages/index/index',
              success() {
                wx.showToast({
                  title: '购买成功',
                  icon: 'success'
                })
              }
            })
          },
          fail: res2 => {
            if (res2.errMsg === 'requestPayment:fail cancel') {
              app.network.post({
                url: app.urls.ORDER_CANCEL,
                data: {
                  order_id: that.data.order_id,
                  prepay_id: that.data.prepay_id
                }
              })
            }
          }
        })
      }
    })
  }
})
