const urls = require('./urls.js')
const brandConfig = require('../brand/config.js')

// 服务器登录
function _login(code, cb) {
  wx.request({
    url: urls.MINI_LOGIN_API_URL,
    data: {
      code
    },
    method: 'POST',
    header: {
      'content-type': 'application/x-www-form-urlencoded'
    },
    success(res) {
      wx.setStorage({
        key: 'userInfo',
        data: res.data.data,
        success() {
          cb(res.data.data)
        }
      })
    },
    complete: () => {
      wx.hideLoading()
    }
  })
}

function _slientLogin(cb) {
  wx.showLoading({
    title: '加载中...',
    mask: true
  })
  const { environment } = wx.getSystemInfoSync()

  if (environment === 'wxwork') {
    wx.login({
      success(res) {
        console.log(res)
        if (res.code) {
          _login(res.code, cb)
        } else {
          wx.showToast({
            title: '微信登录异常',
            icon: 'none'
          })
          wx.hideLoading()
        }
      },
      fail() {
        wx.showToast({
          title: '微信登录异常',
          icon: 'none'
        })
        wx.hideLoading()
      }
    })

    return
  }
  wx.login({
    success(res) {
      if (res.code) {
        _login(res.code, cb)
      } else {
        wx.showToast({
          title: '微信登录异常',
          icon: 'none'
        })
        wx.hideLoading()
      }
    },
    fail() {
      wx.showToast({
        title: '微信登录异常',
        icon: 'none'
      })
      wx.hideLoading()
    }
  })
}

// 静默登录
function login(cb) {
  _slientLogin(cb)
}

function checkLoginStatus(cb) {
  wx.getStorage({
    key: 'userInfo',
    success: res => {
      cb(res.data)
    },
    fail: () => {
      login(cb)
    }
  })
}

function post(params, isTip = true) {
  const finalUrl = `${params.url}?ts=${Date.now()}`
  checkLoginStatus(userInfo => {
    const { user_id } = userInfo
    const data = params.data || {}
    data.user_id = user_id
    wx.request({
      url: finalUrl,
      data,
      method: 'POST',
      header: {
        'content-type': 'application/x-www-form-urlencoded'
      },
      success: res => {
        // success
        wx.hideLoading()
        if (res.data.status !== 200 && isTip) {
          wx.showToast({
            title: res.data.description,
            image: '/resources/alert_fail.svg'
          })

          if (params.fail) {
            params.fail(res)
          }
        } else if (params.success) {
          params.success(res.data)
        }
      },
      fail: res => {
        // fail
        if (params.fail) {
          params.fail(res)
        }
        wx.hideLoading()
        wx.showToast({
          title: '当前网络开小差, 请稍后再试',
          image: '/resources/alert_fail.svg'
        })
      },
      complete: res => {
        // complete

        if (params.complete) {
          params.complete(res)
        }
      }
    })
  })
}

function liveLogin(data) {
  const params = data
  wx.showLoading({
    title: '加载中...',
    mask: true
  })
  wx.login({
    success(res1) {
      if (res1.code) {
        params.code = res1.code
        wx.request({
          url: urls.LIVE.LOGIN,
          data: params,
          method: 'POST',
          header: {
            'content-type': 'application/x-www-form-urlencoded'
          },
          success(res2) {
            wx.setStorage({
              key: 'userInfo',
              data: res2.data.data
            })
          },
          complete: () => {
            wx.hideLoading()
          }
        })
      } else {
        wx.showToast({
          title: '微信登录异常',
          icon: 'none'
        })
        wx.hideLoading()
      }
    },
    fail() {
      wx.showToast({
        title: '微信登录异常',
        icon: 'none'
      })
      wx.hideLoading()
    }
  })
}

module.exports = {
  post,
  login,
  liveLogin
}
